spacepy.irbempy.get_sysaxes — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »

# spacepy.irbempy.get_sysaxes

`spacepy.irbempy.` `get_sysaxes`(dtype, carsph)

  will return the sysaxes according to the irbem library

  Parameters: | - dtype (str) : coordinate system, possible values: GDZ, GEO, GSM, GSE, SM, GEI, MAG, SPH, RLL carsph (str) : cartesian or spherical, possible values: ‘sph’, ‘car’
  Returns: | - sysaxes (int) : value after oner_desp library from 0-8 (or None if not available)

  See also

  `get_dtype`

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- irbempy - Python interface to irbem/ONERA library »